# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.payment_gateway_api import PaymentGatewayApi  # noqa: E501
from killbill.rest import ApiException


class TestPaymentGatewayApi(unittest.TestCase):
    """PaymentGatewayApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.payment_gateway_api.PaymentGatewayApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_build_combo_form_descriptor(self):
        """Test case for build_combo_form_descriptor

        Combo API to generate form data to redirect the customer to the gateway  # noqa: E501
        """
        pass

    def test_build_form_descriptor(self):
        """Test case for build_form_descriptor

        Generate form data to redirect the customer to the gateway  # noqa: E501
        """
        pass

    def test_process_notification(self):
        """Test case for process_notification

        Process a gateway notification  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
