# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.catalog_api import CatalogApi  # noqa: E501
from killbill.rest import ApiException


class TestCatalogApi(unittest.TestCase):
    """CatalogApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.catalog_api.CatalogApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_simple_plan(self):
        """Test case for add_simple_plan

        Add a simple plan entry in the current version of the catalog  # noqa: E501
        """
        pass

    def test_delete_catalog(self):
        """Test case for delete_catalog

        Delete all versions for a per tenant catalog  # noqa: E501
        """
        pass

    def test_get_available_addons(self):
        """Test case for get_available_addons

        Retrieve available add-ons for a given product  # noqa: E501
        """
        pass

    def test_get_available_base_plans(self):
        """Test case for get_available_base_plans

        Retrieve available base plans  # noqa: E501
        """
        pass

    def test_get_catalog_json(self):
        """Test case for get_catalog_json

        Retrieve the catalog as JSON  # noqa: E501
        """
        pass

    def test_get_catalog_versions(self):
        """Test case for get_catalog_versions

        Retrieve a list of catalog versions  # noqa: E501
        """
        pass

    def test_get_catalog_xml(self):
        """Test case for get_catalog_xml

        Retrieve the full catalog as XML  # noqa: E501
        """
        pass

    def test_get_phase_for_subscription_and_date(self):
        """Test case for get_phase_for_subscription_and_date

        Retrieve phase for a given subscription and date  # noqa: E501
        """
        pass

    def test_get_plan_for_subscription_and_date(self):
        """Test case for get_plan_for_subscription_and_date

        Retrieve plan for a given subscription and date  # noqa: E501
        """
        pass

    def test_get_price_list_for_subscription_and_date(self):
        """Test case for get_price_list_for_subscription_and_date

        Retrieve priceList for a given subscription and date  # noqa: E501
        """
        pass

    def test_get_product_for_subscription_and_date(self):
        """Test case for get_product_for_subscription_and_date

        Retrieve product for a given subscription and date  # noqa: E501
        """
        pass

    def test_upload_catalog_xml(self):
        """Test case for upload_catalog_xml

        Upload the full catalog as XML  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
