# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.subscription_api import SubscriptionApi  # noqa: E501
from killbill.rest import ApiException


class TestSubscriptionApi(unittest.TestCase):
    """SubscriptionApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.subscription_api.SubscriptionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_subscription_blocking_state(self):
        """Test case for add_subscription_blocking_state

        Block a subscription  # noqa: E501
        """
        pass

    def test_cancel_subscription_plan(self):
        """Test case for cancel_subscription_plan

        Cancel an entitlement plan  # noqa: E501
        """
        pass

    def test_change_subscription_plan(self):
        """Test case for change_subscription_plan

        Change entitlement plan  # noqa: E501
        """
        pass

    def test_create_subscription(self):
        """Test case for create_subscription

        Create an subscription  # noqa: E501
        """
        pass

    def test_create_subscription_custom_fields(self):
        """Test case for create_subscription_custom_fields

        Add custom fields to subscription  # noqa: E501
        """
        pass

    def test_create_subscription_tags(self):
        """Test case for create_subscription_tags

        """
        pass

    def test_create_subscription_with_add_ons(self):
        """Test case for create_subscription_with_add_ons

        Create an entitlement with addOn products  # noqa: E501
        """
        pass

    def test_create_subscriptions_with_add_ons(self):
        """Test case for create_subscriptions_with_add_ons

        Create multiple entitlements with addOn products  # noqa: E501
        """
        pass

    def test_delete_subscription_custom_fields(self):
        """Test case for delete_subscription_custom_fields

        Remove custom fields from subscription  # noqa: E501
        """
        pass

    def test_delete_subscription_tags(self):
        """Test case for delete_subscription_tags

        Remove tags from subscription  # noqa: E501
        """
        pass

    def test_get_subscription(self):
        """Test case for get_subscription

        Retrieve a subscription by id  # noqa: E501
        """
        pass

    def test_get_subscription_audit_logs_with_history(self):
        """Test case for get_subscription_audit_logs_with_history

        Retrieve subscription audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_subscription_by_key(self):
        """Test case for get_subscription_by_key

        Retrieve a subscription by external key  # noqa: E501
        """
        pass

    def test_get_subscription_custom_fields(self):
        """Test case for get_subscription_custom_fields

        Retrieve subscription custom fields  # noqa: E501
        """
        pass

    def test_get_subscription_event_audit_logs_with_history(self):
        """Test case for get_subscription_event_audit_logs_with_history

        Retrieve subscription event audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_subscription_tags(self):
        """Test case for get_subscription_tags

        Retrieve subscription tags  # noqa: E501
        """
        pass

    def test_modify_subscription_custom_fields(self):
        """Test case for modify_subscription_custom_fields

        Modify custom fields to subscription  # noqa: E501
        """
        pass

    def test_uncancel_subscription_plan(self):
        """Test case for uncancel_subscription_plan

        Un-cancel an entitlement  # noqa: E501
        """
        pass

    def test_undo_change_subscription_plan(self):
        """Test case for undo_change_subscription_plan

        Undo a pending change plan on an entitlement  # noqa: E501
        """
        pass

    def test_update_subscription_bcd(self):
        """Test case for update_subscription_bcd

        Update the BCD associated to a subscription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
