# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.security_api import SecurityApi  # noqa: E501
from killbill.rest import ApiException


class TestSecurityApi(unittest.TestCase):
    """SecurityApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.security_api.SecurityApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_role_definition(self):
        """Test case for add_role_definition

        Add a new role definition)  # noqa: E501
        """
        pass

    def test_add_user_roles(self):
        """Test case for add_user_roles

        Add a new user with roles (to make api requests)  # noqa: E501
        """
        pass

    def test_get_current_user_permissions(self):
        """Test case for get_current_user_permissions

        List user permissions  # noqa: E501
        """
        pass

    def test_get_current_user_subject(self):
        """Test case for get_current_user_subject

        Get user information  # noqa: E501
        """
        pass

    def test_get_role_definition(self):
        """Test case for get_role_definition

        Get role definition  # noqa: E501
        """
        pass

    def test_get_user_roles(self):
        """Test case for get_user_roles

        Get roles associated to a user  # noqa: E501
        """
        pass

    def test_invalidate_user(self):
        """Test case for invalidate_user

        Invalidate an existing user  # noqa: E501
        """
        pass

    def test_update_role_definition(self):
        """Test case for update_role_definition

        Update a new role definition)  # noqa: E501
        """
        pass

    def test_update_user_password(self):
        """Test case for update_user_password

        Update a user password  # noqa: E501
        """
        pass

    def test_update_user_roles(self):
        """Test case for update_user_roles

        Update roles associated to a user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
