# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.tenant_api import TenantApi  # noqa: E501
from killbill.rest import ApiException


class TestTenantApi(unittest.TestCase):
    """TenantApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.tenant_api.TenantApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tenant(self):
        """Test case for create_tenant

        Create a tenant  # noqa: E501
        """
        pass

    def test_delete_per_tenant_configuration(self):
        """Test case for delete_per_tenant_configuration

        Delete a per tenant configuration (system properties)  # noqa: E501
        """
        pass

    def test_delete_plugin_configuration(self):
        """Test case for delete_plugin_configuration

        Delete a per tenant configuration for a plugin  # noqa: E501
        """
        pass

    def test_delete_plugin_payment_state_machine_config(self):
        """Test case for delete_plugin_payment_state_machine_config

        Delete a per tenant payment state machine for a plugin  # noqa: E501
        """
        pass

    def test_delete_push_notification_callbacks(self):
        """Test case for delete_push_notification_callbacks

        Delete a push notification  # noqa: E501
        """
        pass

    def test_delete_user_key_value(self):
        """Test case for delete_user_key_value

        Delete  a per tenant user key/value  # noqa: E501
        """
        pass

    def test_get_all_plugin_configuration(self):
        """Test case for get_all_plugin_configuration

        Retrieve a per tenant key value based on key prefix  # noqa: E501
        """
        pass

    def test_get_per_tenant_configuration(self):
        """Test case for get_per_tenant_configuration

        Retrieve a per tenant configuration (system properties)  # noqa: E501
        """
        pass

    def test_get_plugin_configuration(self):
        """Test case for get_plugin_configuration

        Retrieve a per tenant configuration for a plugin  # noqa: E501
        """
        pass

    def test_get_plugin_payment_state_machine_config(self):
        """Test case for get_plugin_payment_state_machine_config

        Retrieve a per tenant payment state machine for a plugin  # noqa: E501
        """
        pass

    def test_get_push_notification_callbacks(self):
        """Test case for get_push_notification_callbacks

        Retrieve a push notification  # noqa: E501
        """
        pass

    def test_get_tenant(self):
        """Test case for get_tenant

        Retrieve a tenant by id  # noqa: E501
        """
        pass

    def test_get_tenant_by_api_key(self):
        """Test case for get_tenant_by_api_key

        Retrieve a tenant by its API key  # noqa: E501
        """
        pass

    def test_get_user_key_value(self):
        """Test case for get_user_key_value

        Retrieve a per tenant user key/value  # noqa: E501
        """
        pass

    def test_insert_user_key_value(self):
        """Test case for insert_user_key_value

        Add a per tenant user key/value  # noqa: E501
        """
        pass

    def test_register_push_notification_callback(self):
        """Test case for register_push_notification_callback

        Create a push notification  # noqa: E501
        """
        pass

    def test_upload_per_tenant_configuration(self):
        """Test case for upload_per_tenant_configuration

        Add a per tenant configuration (system properties)  # noqa: E501
        """
        pass

    def test_upload_plugin_configuration(self):
        """Test case for upload_plugin_configuration

        Add a per tenant configuration for a plugin  # noqa: E501
        """
        pass

    def test_upload_plugin_payment_state_machine_config(self):
        """Test case for upload_plugin_payment_state_machine_config

        Add a per tenant payment state machine for a plugin  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
