# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.account_api import AccountApi  # noqa: E501
from killbill.rest import ApiException


class TestAccountApi(unittest.TestCase):
    """AccountApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.account_api.AccountApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_account_blocking_state(self):
        """Test case for add_account_blocking_state

        Block an account  # noqa: E501
        """
        pass

    def test_add_email(self):
        """Test case for add_email

        Add account email  # noqa: E501
        """
        pass

    def test_close_account(self):
        """Test case for close_account

        Close account  # noqa: E501
        """
        pass

    def test_create_account(self):
        """Test case for create_account

        Create account  # noqa: E501
        """
        pass

    def test_create_account_custom_fields(self):
        """Test case for create_account_custom_fields

        Add custom fields to account  # noqa: E501
        """
        pass

    def test_create_account_tags(self):
        """Test case for create_account_tags

        Add tags to account  # noqa: E501
        """
        pass

    def test_create_payment_method(self):
        """Test case for create_payment_method

        Add a payment method  # noqa: E501
        """
        pass

    def test_delete_account_custom_fields(self):
        """Test case for delete_account_custom_fields

        Remove custom fields from account  # noqa: E501
        """
        pass

    def test_delete_account_tags(self):
        """Test case for delete_account_tags

        Remove tags from account  # noqa: E501
        """
        pass

    def test_get_account(self):
        """Test case for get_account

        Retrieve an account by id  # noqa: E501
        """
        pass

    def test_get_account_audit_logs(self):
        """Test case for get_account_audit_logs

        Retrieve audit logs by account id  # noqa: E501
        """
        pass

    def test_get_account_audit_logs_with_history(self):
        """Test case for get_account_audit_logs_with_history

        Retrieve account audit logs with history by account id  # noqa: E501
        """
        pass

    def test_get_account_bundles(self):
        """Test case for get_account_bundles

        Retrieve bundles for account  # noqa: E501
        """
        pass

    def test_get_account_by_key(self):
        """Test case for get_account_by_key

        Retrieve an account by external key  # noqa: E501
        """
        pass

    def test_get_account_custom_fields(self):
        """Test case for get_account_custom_fields

        Retrieve account custom fields  # noqa: E501
        """
        pass

    def test_get_account_email_audit_logs_with_history(self):
        """Test case for get_account_email_audit_logs_with_history

        Retrieve account email audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_account_tags(self):
        """Test case for get_account_tags

        Retrieve account tags  # noqa: E501
        """
        pass

    def test_get_account_timeline(self):
        """Test case for get_account_timeline

        Retrieve account timeline  # noqa: E501
        """
        pass

    def test_get_accounts(self):
        """Test case for get_accounts

        List accounts  # noqa: E501
        """
        pass

    def test_get_all_custom_fields(self):
        """Test case for get_all_custom_fields

        Retrieve account customFields  # noqa: E501
        """
        pass

    def test_get_all_tags(self):
        """Test case for get_all_tags

        Retrieve account tags  # noqa: E501
        """
        pass

    def test_get_blocking_state_audit_logs_with_history(self):
        """Test case for get_blocking_state_audit_logs_with_history

        Retrieve blocking state audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_blocking_states(self):
        """Test case for get_blocking_states

        Retrieve blocking states for account  # noqa: E501
        """
        pass

    def test_get_children_accounts(self):
        """Test case for get_children_accounts

        List children accounts  # noqa: E501
        """
        pass

    def test_get_emails(self):
        """Test case for get_emails

        Retrieve an account emails  # noqa: E501
        """
        pass

    def test_get_invoice_payments(self):
        """Test case for get_invoice_payments

        Retrieve account invoice payments  # noqa: E501
        """
        pass

    def test_get_invoices_for_account(self):
        """Test case for get_invoices_for_account

        Retrieve account invoices  # noqa: E501
        """
        pass

    def test_get_overdue_account(self):
        """Test case for get_overdue_account

        Retrieve overdue state for account  # noqa: E501
        """
        pass

    def test_get_payment_methods_for_account(self):
        """Test case for get_payment_methods_for_account

        Retrieve account payment methods  # noqa: E501
        """
        pass

    def test_get_payments_for_account(self):
        """Test case for get_payments_for_account

        Retrieve account payments  # noqa: E501
        """
        pass

    def test_modify_account_custom_fields(self):
        """Test case for modify_account_custom_fields

        Modify custom fields to account  # noqa: E501
        """
        pass

    def test_pay_all_invoices(self):
        """Test case for pay_all_invoices

        Trigger a payment for all unpaid invoices  # noqa: E501
        """
        pass

    def test_process_payment(self):
        """Test case for process_payment

        Trigger a payment (authorization, purchase or credit)  # noqa: E501
        """
        pass

    def test_process_payment_by_external_key(self):
        """Test case for process_payment_by_external_key

        Trigger a payment using the account external key (authorization, purchase or credit)  # noqa: E501
        """
        pass

    def test_rebalance_existing_cba_on_account(self):
        """Test case for rebalance_existing_cba_on_account

        Rebalance account CBA  # noqa: E501
        """
        pass

    def test_refresh_payment_methods(self):
        """Test case for refresh_payment_methods

        Refresh account payment methods  # noqa: E501
        """
        pass

    def test_remove_email(self):
        """Test case for remove_email

        Delete email from account  # noqa: E501
        """
        pass

    def test_search_accounts(self):
        """Test case for search_accounts

        Search accounts  # noqa: E501
        """
        pass

    def test_set_default_payment_method(self):
        """Test case for set_default_payment_method

        Set the default payment method  # noqa: E501
        """
        pass

    def test_transfer_child_credit_to_parent(self):
        """Test case for transfer_child_credit_to_parent

        Move a given child credit to the parent level  # noqa: E501
        """
        pass

    def test_update_account(self):
        """Test case for update_account

        Update account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
