# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.credit_api import CreditApi  # noqa: E501
from killbill.rest import ApiException


class TestCreditApi(unittest.TestCase):
    """CreditApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.credit_api.CreditApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_credits(self):
        """Test case for create_credits

        Create a credit  # noqa: E501
        """
        pass

    def test_get_credit(self):
        """Test case for get_credit

        Retrieve a credit by id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
