# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.invoice_payment_api import InvoicePaymentApi  # noqa: E501
from killbill.rest import ApiException


class TestInvoicePaymentApi(unittest.TestCase):
    """InvoicePaymentApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.invoice_payment_api.InvoicePaymentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_invoice_payment_transaction(self):
        """Test case for complete_invoice_payment_transaction

        Complete an existing transaction  # noqa: E501
        """
        pass

    def test_create_chargeback(self):
        """Test case for create_chargeback

        Record a chargeback  # noqa: E501
        """
        pass

    def test_create_chargeback_reversal(self):
        """Test case for create_chargeback_reversal

        Record a chargebackReversal  # noqa: E501
        """
        pass

    def test_create_invoice_payment_custom_fields(self):
        """Test case for create_invoice_payment_custom_fields

        Add custom fields to payment  # noqa: E501
        """
        pass

    def test_create_invoice_payment_tags(self):
        """Test case for create_invoice_payment_tags

        Add tags to payment  # noqa: E501
        """
        pass

    def test_create_refund_with_adjustments(self):
        """Test case for create_refund_with_adjustments

        Refund a payment, and adjust the invoice if needed  # noqa: E501
        """
        pass

    def test_delete_invoice_payment_custom_fields(self):
        """Test case for delete_invoice_payment_custom_fields

        Remove custom fields from payment  # noqa: E501
        """
        pass

    def test_delete_invoice_payment_tags(self):
        """Test case for delete_invoice_payment_tags

        Remove tags from payment  # noqa: E501
        """
        pass

    def test_get_invoice_payment(self):
        """Test case for get_invoice_payment

        Retrieve a payment by id  # noqa: E501
        """
        pass

    def test_get_invoice_payment_audit_logs_with_history(self):
        """Test case for get_invoice_payment_audit_logs_with_history

        Retrieve invoice payment audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_invoice_payment_custom_fields(self):
        """Test case for get_invoice_payment_custom_fields

        Retrieve payment custom fields  # noqa: E501
        """
        pass

    def test_get_invoice_payment_tags(self):
        """Test case for get_invoice_payment_tags

        Retrieve payment tags  # noqa: E501
        """
        pass

    def test_modify_invoice_payment_custom_fields(self):
        """Test case for modify_invoice_payment_custom_fields

        Modify custom fields to payment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
