# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.models.overdue_state import OverdueState  # noqa: E501
from killbill.rest import ApiException


class TestOverdueState(unittest.TestCase):
    """OverdueState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOverdueState(self):
        """Test OverdueState"""
        # FIXME: construct object with mandatory attributes with example values
        # model = killbill.models.overdue_state.OverdueState()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
