# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.payment_transaction_api import PaymentTransactionApi  # noqa: E501
from killbill.rest import ApiException


class TestPaymentTransactionApi(unittest.TestCase):
    """PaymentTransactionApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.payment_transaction_api.PaymentTransactionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_transaction_custom_fields(self):
        """Test case for create_transaction_custom_fields

        Add custom fields to payment transaction  # noqa: E501
        """
        pass

    def test_create_transaction_tags(self):
        """Test case for create_transaction_tags

        Add tags to payment transaction  # noqa: E501
        """
        pass

    def test_delete_transaction_custom_fields(self):
        """Test case for delete_transaction_custom_fields

        Remove custom fields from payment transaction  # noqa: E501
        """
        pass

    def test_delete_transaction_tags(self):
        """Test case for delete_transaction_tags

        Remove tags from payment transaction  # noqa: E501
        """
        pass

    def test_get_payment_by_transaction_external_key(self):
        """Test case for get_payment_by_transaction_external_key

        Retrieve a payment by transaction external key  # noqa: E501
        """
        pass

    def test_get_payment_by_transaction_id(self):
        """Test case for get_payment_by_transaction_id

        Retrieve a payment by transaction id  # noqa: E501
        """
        pass

    def test_get_transaction_audit_logs_with_history(self):
        """Test case for get_transaction_audit_logs_with_history

        Retrieve payment transaction audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_transaction_custom_fields(self):
        """Test case for get_transaction_custom_fields

        Retrieve payment transaction custom fields  # noqa: E501
        """
        pass

    def test_get_transaction_tags(self):
        """Test case for get_transaction_tags

        Retrieve payment transaction tags  # noqa: E501
        """
        pass

    def test_modify_transaction_custom_fields(self):
        """Test case for modify_transaction_custom_fields

        Modify custom fields to payment transaction  # noqa: E501
        """
        pass

    def test_notify_state_changed(self):
        """Test case for notify_state_changed

        Mark a pending payment transaction as succeeded or failed  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
