# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.custom_field_api import CustomFieldApi  # noqa: E501
from killbill.rest import ApiException


class TestCustomFieldApi(unittest.TestCase):
    """CustomFieldApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.custom_field_api.CustomFieldApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_custom_field_audit_logs_with_history(self):
        """Test case for get_custom_field_audit_logs_with_history

        Retrieve custom field audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_custom_fields(self):
        """Test case for get_custom_fields

        List custom fields  # noqa: E501
        """
        pass

    def test_search_custom_fields(self):
        """Test case for search_custom_fields

        Search custom fields  # noqa: E501
        """
        pass

    def test_search_custom_fields_by_type_name(self):
        """Test case for search_custom_fields_by_type_name

        Search custom fields by type, name and optional value  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
