# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.admin_api import AdminApi  # noqa: E501
from killbill.rest import ApiException


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.admin_api.AdminApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_queue_entries(self):
        """Test case for get_queue_entries

        Get queues entries  # noqa: E501
        """
        pass

    def test_invalidates_cache(self):
        """Test case for invalidates_cache

        Invalidates the given Cache if specified, otherwise invalidates all caches  # noqa: E501
        """
        pass

    def test_invalidates_cache_by_account(self):
        """Test case for invalidates_cache_by_account

        Invalidates Caches per account level  # noqa: E501
        """
        pass

    def test_invalidates_cache_by_tenant(self):
        """Test case for invalidates_cache_by_tenant

        Invalidates Caches per tenant level  # noqa: E501
        """
        pass

    def test_put_in_rotation(self):
        """Test case for put_in_rotation

        Put the host back into rotation  # noqa: E501
        """
        pass

    def test_put_out_of_rotation(self):
        """Test case for put_out_of_rotation

        Put the host out of rotation  # noqa: E501
        """
        pass

    def test_trigger_invoice_generation_for_parked_accounts(self):
        """Test case for trigger_invoice_generation_for_parked_accounts

        Trigger an invoice generation for all parked accounts  # noqa: E501
        """
        pass

    def test_update_payment_transaction_state(self):
        """Test case for update_payment_transaction_state

        Update existing paymentTransaction and associated payment state  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
